rm(list=ls())
library(RchivalTag)
library(abind)
library(oceanmap)
library(lubridate)
library(MASS)
data(cmap)

setwd("~/bluemed")
tracks_file <- "data/bluemed_tracks.rd"
load(tracks_file,verbose = T)

prob_lim <- 0.8
out_file <- paste0("data/SpatialTracks/SpatialTracks_prob",prob_lim,".rd")
load(out_file,verbose = T)

source("funct/get.meta_bluemed.r")
source("funct/textp.r")
source("funct/year.colorbar.r")
source("funct/date_functions.r")
source("funct/plot_SpatialTracks.r")

## the track data includes recovered and transmitted data sets
## in case of recovered tags, recovered and transmitted data sets exist
## recovered data sets are indicated by an extension "_recovered"
tags <- names(final.tracks) 
dubtags <- gsub("_recovered","",tags[grep("recovered",tags)])
tags <- tags[which(!(tags %in% dubtags))] ## remove transmitted datasets from recovered tags
tags <- tags[which(!grepl('08A0970',tags))] # disregard old MK10 from JM

df_cols <- data.frame(yday=1:366,col=colorRampPalette(cmap$year.jet)(366),stringsAsFactors = F)

bft.tracks <- c()
for(tag in tags){
  add <- final.tracks[[tag]][,c('date','Lon','Lat',"Serial")]
  bft.tracks <- rbind(bft.tracks,add)
}

Lims <- list(c(-6.0, 16.5, 33.0, 44.5))
reg <- list()
for(i in 1){
  mat <- kde2d(bft.tracks$Lon,bft.tracks$Lat,h=1,n = 500,lims = Lims[[i]])
  mat$z[mat$z <= 0.000001] <- NA
  mat$z <- mat$z*100/max(mat$z,na.rm=T)
  reg[[i]] <- raster(mat)
}

### deployment and pop-up data:
meta <- get.meta_bluemed(year = 2015:2016)
meta$color <- "darkgreen"; meta$color[which(meta$dep.year == 2016)] <- "blue"

plot_zone <- extent(c(2.5,6.5,41,44))
tuna_zone <- extent(c(3,6,41.5,44))

## start plotting:
do.save <- F
plot_folder <- "./plots/Fig4_probability_maps/"
width <- 6.640600 ; height <- 7.797988
if(do.save) figure("Fig4_probability_maps",plot_folder,do.save=do.save,width=width,height=height,type='jpg')
if(!do.save) x11(width=width,height=height) 
data(cmap)

# define margins of the colorbars:
cbx <- c(17.68233, 18.17913)
cby <- c(32.6, 44.9)

par(mfrow=c(2,1),mar=c(3,3,1,4)) ## setup plotting window (2 vertically aligned subplots)
Lims2 <- extent(Lims[[1]])

## plot individual tracks, colored by day of the year
plotmap(Lims2,grid = F,axeslabels = F,las=0,col.land = NA,bwd=0,axes = F,border=NA) ## empty plot required for scaling
plot_SpatialTracks(SpatialTracks, show_merged = F)
plotmap(Lims2,grid = F,grid.res = 5,axeslabels = F,las=0,bwd = 2,add=T)
year.colorbar(cbx,cby,cex.cb.ticks = .6)
textp(9,92,text = "a)",font=2,cex=1.2)

## plot kernel density map
plotmap(Lims2,grid = F,axeslabels = F,las=0,col.land = NA,bwd=0,axes = F,border=NA) ## empty plot required for scaling
image(reg[[1]],add=T,col=cmap$jet,zlim=c(0,100))
plotmap(Lims2,grid = F,grid.res = 5,axeslabels = F,las=0,bwd = 2,add=T)
set.colorbar(cbx,cby, cb.xlab="Kernel Density (%)",cb.xlab.line=.2)
textp(9,92,text = "b)",font=2,cex=1.2)

close_fig(do.save)




