
rm(list = ls())
library(RchivalTag)
library(oceanmap)

## load required functions
setwd("~/bluemed/")
source('funct/in.zone.r')
source('funct/date_functions.r')
source('funct/textp.r')

## load required data sets:
load("data/bluemed_DepthTS_validated.rd",verbose=T)
tags <- names(tsets)
length(tags)

## combine time series data of different tags in one data frame:
library(plyr)
out <- c()
for (itag in tags) {
  cat("Running tag",itag,'\n')
  tagdata <- tsets[[itag]]
  resol <- as.numeric(min(difftime(tagdata$date.long[2],tagdata$date.long[1],units="secs"),na.rm=T))
  npoints10 <- 600/resol #number of points corresponding to 10 minutes (600 seconds)
  tagdata <- tagdata[seq(1, nrow(tagdata), npoints10), ]
  ii <- which(tagdata$daytime == "Day" & tagdata$nrecs_perc_Day == 100)
  tagdata <- tagdata[ii,]
  tagdata <- subset(tagdata,!is.na(tagdata$Lon))
  tagdata <- in.zone(tagdata)
  tagdata <- subset(tagdata,in.zone==T) # only consider data inside the Gulf of Lions
  tagdata$month <- date2month(tagdata$date)
  tagdata$year <- date2year(tagdata$date)
  out <- rbind(out, tagdata[,c('Serial','month','date','Depth')])
}
head(out)

## summary tables
ddply(out,.(Serial),function(x)c(ndays=length(unique(x$date)))) ## number of days per tag
ddply(out,.(Serial,month),function(x)c(ndays=length(unique(x$date))))  ## number of days per tag and month


out$Ptt <- out$Serial
months <- unique(out$month)
months <- months[order(months)]
folder <- "./plots"

## start plotting
do.save <- F
figure(folder = folder,filename = "Fig5_Histograms",do.save=do.save,type="eps")
par(mfrow=c(3,3))
for(m in months){
  ## create and plot Time at Depth histograms from time series data: 
  hist_tad(out[which(out$month == m),],bin_breaks = c(0,10,20,50,100,200,300,400,600,1000),do_mid.ticks = F,cex=1)
  textp(70,90,text = num2month(m),cex=1.2,font=2,total.reg = F)
  par(new=F)
}
close_fig(do.save)
  