
rm(list = ls())
library(lubridate)
library(ggplot2)
detach("package:dplyr", unload=TRUE)
detach("package:plyr", unload=TRUE)
require(dplyr)
library(plyr)
library(ggplot2)

setwd("~/bluemed")

source("funct/in.zone.r")
plot_folder <- "./plots/"


### load and select data ##############################################################

load("data/bluemed_DepthTS_validated.rd", verbose=T)
summary(tsets)
tags  <- names(tsets)
tags  <- tags[which(grepl('P', tags))] ## omit old mk10 tag

#consider only recovered tags
tagrec  <- tags[which(grepl('recovered', tags))] # take only recovered tags

#find resolution of recovered DepthTS (in seconds) ################################################################

resolution  <- c()
for (itag in tagrec) {
  cat("Running tag", itag, '\n')
  tagdata <- tsets[[itag]]
  head(tagdata)
  add  <- data.frame(tagname=itag)
  tagdata$date.longct <- as.POSIXct(tagdata$date.long)
  yy <- lag(tagdata$date.longct)
  head((tagdata$date.longct))
  tagdata$difftime <- c(NA, diff(tagdata$date.longct, units="secs"))
  add$resol  <- tagdata$difftime[2]
  add$MinDate <- min(na.omit(tagdata$date.longct))
  add$MaxDate <- max(na.omit(tagdata$date.longct))
  resolution  <- rbind(resolution, add)
}
resolution


##### calculate % presence around surface points #######################################################################

surfacedepth=1 ## surface layer limit in meters 

depthbins  <- c(seq(from=0, to=100, by=1), seq(from=100, to=200, by=10), 300, 500) # create depth bins in meters
widthinterval <- 600 # lower sampling interval to 600 seconds

j <- widthinterval
freqtableall <- data.frame("bin"=depthbins, "Freq"=rep(0, length(depthbins)))
freqtable_tag_all <- freqtablemonthall <- list()

for (itag in tagrec) { ## run on each recovered tag
  cat("Running tag", itag, "widthinterval=", j, "sec", '\n')
  
  ## subset data
  tagdata <- tsets[[itag]]
  tagdata <- subset(tagdata, !is.na(tagdata$Lon))
  tagdata <- in.zone(tagdata)
  tagdata <- subset(tagdata, in.zone==T) #only consider data in zone of Gulf of Lions (see Figure 1)
  tagdata$month <- tagdata$date.long$mon + 1
  tagdata <- subset(tagdata, tagdata$month %in% 8:10)
  
  if(nrow(tagdata) > 0){
    tagdata$surface  <- tagdata$Depth <= surfacedepth
    
    #define interval around surface points
    interval=j/subset(resolution, tagname==itag)$resol #number of points corresponding to widthinterval according to resolution
    tagdata$startpoint <- sample(1:interval, nrow(tagdata), TRUE) # number of points before reference point (randomly set)
    tagdata$endpoint <- interval-tagdata$startpoint # number of points after reference point (depends on number of points before reference point): before & after = 200
    isOnSurface <- which(tagdata$surface & tagdata$daytime=="Day") # index of surfacing records at daytime
    
    ## Depth values at the beginning and end of each window around surface events:
    resDepth  <- lapply(isOnSurface, function(x) tagdata$Depth[c((x-tagdata$startpoint[x]), (x+tagdata$endpoint[x]))])
    resDepth  <- unlist(resDepth)
    
    ## transform dataframe with frequencies (counts) per bin number 
    resDepthCat <- depthbins[findInterval(x = resDepth, vec = depthbins)] ## get depth bins corresponding to depth values
    freqtable <- as.data.frame(table(resDepthCat))
    names(freqtable) <- c("bin", "Freq")
    freqtable$cumul <- freqtable$Freq
    
    ## merge with frequency data of all tags 
    tt <- merge(freqtableall, freqtable, by=c("bin"), all.x=T)
    head(tt)
    freqtableall$Freq <- freqtableall$Freq+ifelse(is.na(tt$Freq.y), 0, tt$Freq.y)
    freqtableall$cumul <- cumsum(freqtableall$Freq/sum(freqtableall$Freq)*100) ## updated during each loop iteration
    head(freqtableall)
    
    # keep copy of frequency data of single tags
    tag <- paste0(itag,"_600s")
    freqtable_tag_all[[tag]]$Freq <- ifelse(is.na(tt$Freq.y), 0, tt$Freq.y) ## take data from temporary merged data frame so that all bin numbers are included
    freqtable_tag_all[[tag]]$cumul <- cumsum(freqtable_tag_all[[tag]]$Freq/sum(freqtable_tag_all[[tag]]$Freq)*100)
  }
}
head(freqtable_tag_all[[1]])

subtags <- names(freqtable_tag_all)
n_tags <- length(subtags)
# mean and standard deviation over tagged individuals  
freqtableall_tag <- data.frame("bin"=depthbins, "cumul"=0, "sd" = 0)

for(tag in subtags) freqtableall_tag$cumul <- freqtableall_tag$cumul + freqtable_tag_all[[tag]]$cumul
freqtableall_tag$cumul <- freqtableall_tag$cumul/n_tags

for(tag in subtags)  freqtableall_tag$sd <- freqtableall_tag$sd + (freqtableall_tag$cumul-freqtable_tag_all[[tag]]$cumul)^2 ## based on cumul values -> seperate loop
freqtableall_tag$sd <- sqrt(freqtableall_tag$sd/n_tags)
head(freqtableall_tag)


######## PLOTTING Fig9_cum_curves_recovered_tags_1m_sd.png
#average curve with error over tagged individuals
source("funct/add.legend.r")

do.save <- F
ftype <- "png"
if(!do.save) x11(width=6, height=6)
if(do.save) figure(paste0("Fig9_cum_curves_recovered_tags_sd"), folder = plot_folder, do.save=do.save, width=6, height=6, type=ftype)

plot(freqtableall_tag$bin, freqtableall_tag$cumul, xlim=c(0, 100), xlab="Depth  (m)", ylab="Cumulative depth records > x (%)", main="", pch=19)
arrows(freqtableall_tag$bin, freqtableall_tag$cumul-freqtableall_tag$sd, freqtableall_tag$bin, freqtableall_tag$cumul+freqtableall_tag$sd, length=0.05, angle=90, code=3)
abline(v=c(10, 20), col="grey")
abline(h=c(90), col="grey")

close_fig(do.save)

