
rm(list = ls())
detach("package:dplyr", unload=TRUE)
library(RchivalTag)
library(plyr)

setwd("~/bluemed/")

source('funct/get.meta_bluemed.r')
source('funct/merge.multi_args.r')
source('funct/date_functions.r')
source('funct/add.legend.r')


load('data/bluemed_DepthTS_validated.rd',verbose = T)
load("data/pdt_data_recovered_tags.rd",verbose = T)


###########" create sampling depths:
input <-  pdt_all[which(pdt_all$NumBins == 8),c("DeployID","date",'Depth','datetime')]
input$datetime_nm <- as.numeric(input$datetime)
head(input)

sm.maxDepths <- ddply(input[,c("DeployID","Depth","datetime_nm")],.(DeployID,datetime_nm),function(x)c(maxDepth=max(x$Depth),nrec=nrow(x)))

input2 <- merge.multi_args(input,sm.maxDepths,c("DeployID","datetime_nm"))
input2 <- input2[which(input2$nrec == 8),] ## assure that only pdt8 was taken!

sm.samples_per_maxDepth <- ddply(sm.maxDepths[which(sm.maxDepths$nrec == 8),],.(maxDepth),function(x)c(n=unique(nrow(x)))) ### check number of sample schemes per maxDepth

pdt_samples <- list()
maxDepths <- unique(input2$maxDepth)
maxDepths <- maxDepths[order(maxDepths)]
for(maxDepth in maxDepths){
  u <- input2[which(input2$maxDepth == maxDepth),]
  u$i <- as.numeric(as.factor(paste(u$DeployID,u$date)))
  i <- 1
  for(i in unique(u$i)){
    pdt_samples[[paste0("maxDepth_",maxDepth)]][[i]] <- u[which(u$i== i),]
  }
}

###########" load and interpolate recovered DepthTempTS tag data:
tags <- get.meta_bluemed(only_recovered = T,year = 2015:2016)$Serial
ctd_sets <- list()
for(tag in tags){
  tag0 <- paste0(tag,"_recovered")
  DepthTS <- tsets[[tag0]]
  DepthTS <- DepthTS[which(!is.na(DepthTS$Depth)),]
  head(DepthTS)
  ctd_sets[[tag]] <- interpolate_PDTs(DepthTS,Temp_field = "Temperature")[[1]]
}


### check maximum depths of recovered data sets:
ts.info <- c()
for(tag in tags){
  i <- apply(ctd_sets[[tag]]$Temperature_matrix,2,function(x)tail(which(!is.na(x)),1))
  add <- data.frame(tag=tag,date=ctd_sets[[tag]]$Date, maxDepth=ctd_sets[[tag]]$Depth[i], col.id=1:length(i))
  ts.info <- rbind(ts.info,add)
  #   interpolate.pdt()
}

## check number of daily recoverd DepthTS data available for each maxDepth:
ts.sm <- ddply(ts.info,.(maxDepth),function(x) c(n=nrow(ts.info[which(ts.info$maxDepth >= x$maxDepth[1]),]))) 
plot(ts.sm$maxDepth,ts.sm$n)


### set maxDepth until which correlation should be evaluated:
test_Depth_limit <- 200
# ts.sm[which(ts.sm$maxDepth == test_Depth_limit),]$n ## number at depth limit

#### idea: apply diffrent pdt sample schemes to same ts profile and test accuracy of derived tcline and strat.index

### select input interpolated data with maxDepth >= test_Depth_limit:
dat.input <- ts.info[which(ts.info$maxDepth >= test_Depth_limit),]


### check correlation:

i <- 1
all.pdt.stats <- list()
dd <- nrow(dat.input)
for(maxDepth in seq(88,test_Depth_limit,by=8)){
  # for(maxDepth in seq(112,,200,by=8)){
  add <- c()
  cat('\nrunning maxDepth',maxDepth)
  for(i in 1:dd){
    # perc.done(i,n = dd)
    dat <- dat.input[i,]
    Temp <- ctd_sets[[dat$tag]]$Temperature_matrix[,dat$col.id]
    Depth <- ctd_sets[[dat$tag]]$Depth
    Date <- ctd_sets[[dat$tag]]$Date[dat$col.id]
    TempProfile <- data.frame(Temp,Depth,Date=Date)
    #   head(TempProfile)
    octd <- list(Temperature_matrix=as.matrix(Temp), Depth=Depth, Date=Date)
    ostats <- get_thermalstrat(octd)
    
    pdt.stats <- c()
    cbs <- pdt_samples[[paste0("maxDepth_",maxDepth)]]
    cb <- 1
    cbii <- sample(1:length(cbs),15,replace = T) ### take equal number (15) of pdt samples per Temp profile
    for(cb in cbii){
      depths <- cbs[[cb]]$Depth
      ii <- which(Depth %in% depths)
      pdt.ctd <- interpolate_PDTs(TempProfile[ii,],Depth_res = .5,Temp_field = "Temp",show_info = F)
      pdt.ctd$station.1$Date <- Date
      add.pdt.stats <- get_thermalstrat(pdt.ctd,show_info = F)
      add.pdt.stats$maxDepth <- maxDepth
      add.pdt.stats$cb <- cb
      pdt.stats <- rbind(pdt.stats,add.pdt.stats)      
    }
    ## add original indices from recovered data (see above)
    pdt.stats$otgrad <- ostats$tgrad
    pdt.stats$otcline <- ostats$tcline
    pdt.stats$ostrat_index <- ostats$strat_index
    pdt.stats$dates <- ostats$dates
    add <- rbind(add,pdt.stats)
  }
  all.pdt.stats[[paste0("maxDepth_",maxDepth)]] <- add
}

save.name <- "data/pdt_DepthTempTS_strat_comp_data.rd"
origin <- "FigS1_pdt_accuracy.R"
save(all.pdt.stats, test_Depth_limit ,origin,file=save.name)
load("data/pdt_DepthTempTS_strat_comp_data.rd")


############ plot cor vs pdt_depth

do.save <- F
folder <- "./plots"
figure("FigS1_pdt_accuracy",folder,width=6.6,height=6.6,do.save=do.save,type="png")

library(oceanmap); data(cmap)

head(all.pdt.stats$maxDepth_48)
names(all.pdt.stats)
nn <- length(all.pdt.stats)
Colors <- colorRampPalette(cmap$jetrev)(nn)
pchs <- c(15,17,19)
vars <- c('tcline','tgrad',"strat_index")
i <- 1
label <- "normalized standard deviation"

maxDepths <- as.numeric(gsub("maxDepth_","",names(all.pdt.stats)))
empty.plot(xlim=range(maxDepths),ylim=c(0,1),ylab="Correlation",xlab="maxmium PDT profile depth (m)")
abline(v=88,lty="dashed")

for(j in 1:3){
  pp <- c()
  for(mm in 1:nn){
    comp <- all.pdt.stats[[mm]]
    pch <- pchs[j]
    
    vals <- vars[j]
    ref_vals <- paste0("o",vals)
    R <- cor(comp[[ref_vals]], comp[[vals]])
    pp <- rbind(pp,data.frame(maxDepth=maxDepths[mm],R=R,col=j+1))
  }
  lines(pp$maxDepth,pp$R,col=j+1)
  points(pp$maxDepth,pp$R,pch=pch,col=j+1)
}
box()
axis(1)
axis(2)
add.legendp(70,15,vals=c("thermocline depth","thermocline gradient","stratification index"),pch=pchs,lwd=0,horiz = F,cex=.8,pt.cex=1.5,text.font=1,col=2:4)
close_fig(do.save)




