rm(list = ls())

library(RchivalTag)
library(oceanmap)
library(lubridate)
data(cmap)

source("funct/plot_SpatialTracks.r")
source("funct/get.meta_bluemed.r")

setwd("~/bluemed/")

track_files <- "data/bluemed_tracks.rd"
load(track_files,verbose = T)

ext <- extent(c(-6.0, 16.5, 33.0, 44.5))

## Spatial Tracks are based on get_geopos() function of the R-package RchivalTag that reads in netcdf-files from the GPE3 runs.
### check which SpatialTracks can be combined
sptrack_files <- Sys.glob('data/SpatialTracks/SpatialTracks_prob*')
for(n in sptrack_files){
  load(n,verbose = F)
  add <- data.frame(tags=names(SpatialTracks))
  # add <- 
  add$class <- unlist(llply(SpatialTracks,function(x){class(x)[1]}))
  out <- round(100*nrow(add[which(add$class != "try-error"),])/nrow(add),1)
  print(paste(n, out,"%"))
}


data(cmap)
prob_lim <- 0.8
out_file <- paste0("data/SpatialTracks/SpatialTracks_prob",prob_lim,".rd")
load(out_file,verbose = T)
for(n in names(SpatialTracks)) {if(class(SpatialTracks[[n]]) == "try-error") print(n)}
df_cols <- data.frame(yday=1:366,col=colorRampPalette(cmap$year.jet)(366),stringsAsFactors = F)

meta0 <- get.meta_bluemed(year = 2015:2016); 
tags <- paste0(meta0$Serial,c("","_recovered")[1+meta0$recovered])
do.save <- F
plot.folder <- "./plots"
figure(file="tracks_map_geopos",folder = plot.folder,height=17,width=13,type = "png",do.save=do.save)
par(mfrow=c(6,4),mar=c(1,2,1,3))
for(tag in tags){
  meta <- get.meta_bluemed(gsub("_recovered","",tag))
  track <- SpatialTracks[[tag]]
  Title <- paste0(meta$Serial," - ",as.Date(meta$dep.date)," : ",as.Date(meta$pop.date))
  plotmap(ext,grid=F,axeslabels = F,las=0,grid.res = 10,main=""); 
  points(meta$dep.lon,meta$dep.lat,pch=24,bg=df_cols$col[yday(meta$dep.date)],col=NA)
  plot_SpatialTracks(track,show_merged = F)
  plotmap(ext,grid=F,axeslabels = F,las=0,grid.res = 10,main="",add=T); title(Title,line = -1)
  points(meta$pop.lon,meta$pop.lat,pch=25,bg=df_cols$col[yday(meta$pop.date)],col=NA)
}
close_fig(do.save)


graphics.off()
library(oceanmap)
figure(file="cbar",folder = plot.folder, height=2,width=13,type = "png",do.save=do.save)
# par(new=T)
year.colorbarp(c(10,90),c(40,60),total.reg = T,cex=1.4,
               cb.xlab = "Deployment day",cex.cb.xlab=1.9,,cb.ticks.ypos=.3,cb.xlab.line=4)#,pal="year.jet",ticks="")
close_fig(do.save)

setwd(plot.folder)
system(paste0('convert tracks_map_geopos.png cbar.png -append ',"../FigS2_individual_tracks_maps.png"))
