
rm(list = ls())
library(mefa)
library(RchivalTag)
library(oceanmap)
library(plyr)
library(lubridate)

setwd("~/bluemed/")
source('funct/in.zone.r')
source('funct/date_functions.r')
source('funct/plot.errorbars.r')
source('funct/load_strat.index.r')
source('funct/textp.r')
source('funct/yday2month.axis.r')

load("data/bluemed_DepthTS_validated.rd",verbose=T)
tags <- names(tsets)

#consider only recovered tags
tagrec <- tags[which(grepl('recovered',tags))]
tagrec <- gsub('_recovered',"",tagrec)

## create dataframe with the daily time each tag spent in different layers in percent:
out <- c()
for (itag in tags) {
  cat("Running tag",itag,'\n')
  tagdata <- tsets[[itag]]
  resol <- as.numeric(min(difftime(tagdata$date.long[2],tagdata$date.long[1],units="secs"),na.rm=T))
  npoints10 <- 600/resol #number of points corresponding to 10 minutes (600 seconds)
  tagdata <- tagdata[seq(1, nrow(tagdata), npoints10), ]
  tagdata <- subset(tagdata,!is.na(tagdata$Lon))
  tagdata <- in.zone(tagdata)
  tagdata <- subset(tagdata,in.zone==T) #only consider in zone
  tagdata$month <- date2month(tagdata$date)
  ii <- which(tagdata$daytime == "Day" & tagdata$nrecs_perc_Day == 100)
  tagdata <- tagdata[ii,]
  tagdata$year <- date2year(tagdata$date)
  
  add2 <- ddply(tagdata,.(Serial,date,year),function(x){
    n <- nrow(x)
    perc_VSL_1m <- 100*nrow(x[which(x$Depth <= 1),])/n
    perc_VSL_2m <- 100*nrow(x[which(x$Depth <= 2),])/n
    perc_NSL_10m <- 100*nrow(x[which(x$Depth <= 10),])/n
    perc_NSL_20m <- 100*nrow(x[which(x$Depth <= 20),])/n
    perc_DL_10m <- 100*nrow(x[which(x$Depth > 10),])/n
    perc_DL_20m <- 100*nrow(x[which(x$Depth > 20),])/n
    c(perc_VSL_1m=perc_VSL_1m,perc_VSL_2m=perc_VSL_2m,
      perc_NSL_10m=perc_NSL_10m,perc_NSL_20m=perc_NSL_20m,
      perc_DL_10m=perc_DL_10m,perc_DL_20m=perc_DL_20m)
  })
  print(paste(nrow(add2),"days"))
  out <- rbind(out,add2) # keep only tags with at least 7 days of data
  # if(nrow(add2) >= 7) out <- rbind(out,add2) # keep only tags with at least 7 days of data
}

out$yday <- lubridate::yday(out$date)
head(out)


# options(warn=1)
kernel_list <- list()
for(i in 1:2){
  for(year in 2015:2016){
    ## subset data:
    dat0 <- out[which(out$year %in% year),]
    min_yday <- lubridate::yday(as.Date("2016-04-15"))
    ydays_df <- data.frame(yday=min_yday:max(dat0$yday))
    for(layer in c("VSL","NSL","DL")){
      dat <- dat0
      if(layer == "VSL") dat <- dat0[which(dat0$Serial %in% tagrec),]
      
      layer0 <- names(dat)[grep(layer,names(dat))][i]
       dat$perc <- dat[[layer0]]
      ref_Depth <- gsub('perc_',"",layer0)
      
      for(f0 in c(0)){
       print(paste("running",year,ref_Depth))
        f <- f0*2+1
        window <- paste0("w_",f,"d")
        ########### kernel 90%
        if(f0 == 0){
          same_day <- ddply(ydays_df, .(yday), function(y){
            YDAY <- y$yday
            days <- (YDAY-f0):(YDAY+f0)
            # print(length(days))
            x <- dat[which(dat$yday %in% days),]
            dd <- unique(x$date); dd <- dd[order(dd)]
            ii <- length(dd)
            # if(ii > f+1) {
            #   print(YDAY)
            #   print(yday2date(days,year))
            #   print(dd)
            #   cat('\n')
            # }
            c(ntags=length(unique(x$Serial)),
              ndays=length(dd),
              nrec=nrow(x),
              mean_perc=mean(x$perc,na.rm=T),
              sd_perc=sd(x$perc,na.rm=T))
          })
          kernel_list[[paste0('year_',year)]][[paste0(ref_Depth)]][[window]] <- same_day
          
        }else{
          
          add <- ddply(ydays_df, .(yday), function(y){
            YDAY <- y$yday
            # print(YDAY)
            days <- (YDAY-f0):(YDAY+f0)
            u <- dnorm(days,mean = YDAY,sd=f0/2)
            u <- 100*u/sum(u)
            sum(u)
            # print(length(days))
            x0 <- dat[which(dat$yday %in% days),]
            add2x <- data.frame(yday=days,w=u*100)
            add2x
            x2 <- merge(x0,add2x,by="yday")
            x <- mefa:::rep.data.frame(x2,times=round(x2$w))
            
            dd <- unique(x$date); dd <- dd[order(dd)]
            # ii <- length(dd)
            # if(ii > f+1) {
            #   print(YDAY)
            #   print(yday2date(days,year))
            #   print(dd)
            #   cat('\n')
            # }
            c(ntags=length(unique(x$Serial)),
              ndays=length(dd),
              nrec=nrow(x),
              mean_perc=mean(x$perc,na.rm=T),
              sd_perc=sd(x$perc,na.rm=T))
          })
          # stop()
          kernel_list[[paste0('year_',year)]][[paste0(ref_Depth)]][[window]] <- add
        }
      } # f0 (window size)
    } # layer (VSL, NSL, DL)
  } # year
} # i reference Depth



############## start plotting:
library(oceanmap); data(cmap)
source("funct/error.band.r")
plot_folder <- "./plots"

do.save <- T
for(i in 1:3){ ## plot Figure 6 and 7 together in a loop
  Fig <- c('Fig6','Fig7',"FigS3")[i] 
  ref_Depth <- c("NSL_20m", "VSL_1m","NSL_10m")[i] ## define layer. NSL_10m corresponds to FigS3
  layer <- substr(ref_Depth,1,3)
  
  if(layer == "VSL" | layer == "NSL") ref_Depth0 <- paste0("(0-",substr(ref_Depth,5,nchar(ref_Depth)),")")
  if(layer == "DL") ref_Depth0 <- paste0("(>",substr(ref_Depth,5,nchar(ref_Depth)),")") ## for other layer selections (not used here)
  
  YEARS <- names(kernel_list)
  figname <- paste0(Fig, "_raw_precence_",ref_Depth,"_all_tags")
  if(layer == "VSL") figname <- paste0(Fig, "_raw_precence_",ref_Depth,'_recovered_tags')
  if(do.save) figure(figname,folder=plot_folder,width=9.3,height=8.8/2,do.save = do.save,xpos=1,type = "png")
  if(!do.save) x11(width=9.3,height=8.8/2)
  n <- length(kernel_list[[1]][[1]]) # number of windows
  par(mfrow=c(1,2))
  
  for(YEAR in YEARS){
    year <- gsub('year_','',YEAR)
    
    windows <- names(kernel_list[[YEAR]][[ref_Depth]])
    for(j in 1:n){
      window <- windows[j]
      w <- gsub('w_','',window)
      
      xlim <- lubridate::yday(range(as.Date(c("2016-04-01","2016-11-30"))))
      ylim <- c(0,100)
      
      mars <- list(a=c(4,3.5,4,.5),b=c(4,3,4,1),c=c(4,2,4,2),d=c(4,1,4,3),e=c(4,0,4,4)) #c(bottom, left, top, right)
      # if(min.Depth == 10) mars <- list(a=c(4,4,4,0),b=c(4,3,4,1),c=c(4,2,4,2),d=c(4,1,4,4),e=c(4,6,4,5)) #c(bottom, left, top, right)
      
      par(mar=mars[[j]],xaxs="i")
      dat <- kernel_list[[paste0('year_',year)]][[ref_Depth]][[window]]
      head(dat)
      y <- dat$mean_perc
      
      empty.plot(xlim=xlim,ylim=ylim);
      plot.errorbars(x = dat$yday, up = y-dat$sd_perc, low = y+dat$sd_perc,epsilon = 2)
      points(dat$yday,y,pch=19,col="blue")
      axis(2,lwd = 0,lwd.ticks = 1)
      
      f <- as.numeric(gsub("d","",w))
      strat <- load_strat.index(year = year,f = f)
      par(new=T,xaxs="i")
      empty.plot(xlim=xlim,ylim=c(0,4.5),main="",xlab="",ylab="",axes=F)
      strat <- strat[which(strat$yday > 40),]
      lines(strat$yday,strat$strat.rmean_in.zone,lwd=3,col="orange")
      
      
      if(j == 1 & w == "1d") {
        mtext(side=2,"Frequency (%)",las=0,line=2.2)
        
        textp(4,90,text=year,font=2,cex=2)
        # textp(8,78,text=paste(layer,ref_Depth0),font=2,cex=1.8)
        
        # title("same-day",line=1)
      }else{
        
        # if(YEAR == YEARS[1]) 
        fout <- paste0(f,"d kernel")
        title(bquote(italic(w) == .(fout)),line=1)
        
        # if(YEAR == YEARS[1]) title(paste0("??",f0,"d kernel"),line=1)
      }
      if(w == "31d") {
        axis(4,lwd = 0,lwd.ticks = 1)
        mtext(side=4,"Thermal stratification index",las=0,line=2.2)
      }
      yday2month.axis(months = 4:11,xpd=F)
      box()
    }
  }
  usr <- par()$usr
  # if(i == 1) 
  abline.global(h=usr[3])
  textp(paste(layer,ref_Depth0),xp = 50,90,adj=.5,font=2,cex=1.8,total.reg = T)
  close_fig(do.save)
  if(!do.save) stop()
} # Year

