

rm(list = ls())
library(lubridate)
library(ggplot2)
detach("package:dplyr", unload=TRUE)
detach("package:plyr", unload=TRUE)
require(dplyr)
library(plyr)
library(ggplot2)

setwd("~/bluemed")

source("funct/in.zone.r")
plot_folder <- "./plots/"


### load and select data ##############################################################

load("data/bluemed_DepthTS_validated.rd", verbose=T)
summary(tsets)
tags  <- names(tsets)

#consider only recovered tags
tagrec  <- tags[which(grepl('recovered', tags))] # take only recovered tags

#find resolution of recovered DepthTS (in seconds) ################################################################

resolution  <- c()
for (itag in tagrec) {
  cat("Running tag", itag, '\n')
  tagdata <- tsets[[itag]]
  head(tagdata)
  add  <- data.frame(tagname=itag)
  tagdata$date.longct <- as.POSIXct(tagdata$date.long)
  yy <- lag(tagdata$date.longct)
  head((tagdata$date.longct))
  tagdata$difftime <- c(NA, diff(tagdata$date.longct, units="secs"))
  add$resol  <- tagdata$difftime[2]
  add$MinDate <- min(na.omit(tagdata$date.longct))
  add$MaxDate <- max(na.omit(tagdata$date.longct))
  resolution  <- rbind(resolution, add)
}
resolution


###CRTs at surface at daytime in zone for recovered tags ############################################################################################
surfacedepth=1 ## surface layer limit in meters 
detach("package:dplyr", unload=TRUE)
detach("package:plyr", unload=TRUE)
library(dplyr)

CRT_VSL <- data.frame("changesurface"=numeric(), "TagID"=character(), "Start"=as.POSIXct(character()), "End"=as.POSIXct(character()), "Month"=numeric(), "CRT_VSLduration"=numeric())

for (itag in tagrec) {
  cat("Running tag", itag, '\n')
  tagdata <- tsets[[itag]]
  resol=subset(resolution, tagname==itag)$resol #number of points corresponding to 10 minutes (interval = 200 when frequency of sampling is 3sec)
  #apply same resolution of 15 seconds to all tags####################################
  npoints15 <- 15/resol #number of points corresponding to 15 seconds
  tagdata <- tagdata[seq(1, nrow(tagdata), npoints15), ]
  resol=15
  tagdata <- subset(tagdata, daytime=="Day")
  tagdata <- in.zone(tagdata)
  tagdata <- subset(tagdata, in.zone==T)
  tagdata$month <- tagdata$date.long$mon+1
  tagdata$day <- tagdata$date.long$mday
  tagdata$surface  <- tagdata$Depth <= surfacedepth
  tagdata$date.long <- as.POSIXct(tagdata$date.long)
  #crt, cat surf
  tagdata$changesurface <- cumsum(c(0, (diff(tagdata$surface))!=0 | (diff(tagdata$day))!=0))
  tagdataCRT_VSL <- subset(tagdata, tagdata$surface==T)

  # estimate crt duration in hours
  CRT_VSL <- rbind(CRT_VSL, as.data.frame(tagdataCRT_VSL %>% group_by(changesurface) %>% 
                                 summarise(TagID=itag, Start = min(date.long), End=max(date.long), Month=min(month), CRT_VSLduration=sum(surface)*resol/3600)))
}  
CRT_VSL <- subset(CRT_VSL, CRT_VSL$Month %in% 8:10) #consider only August-October


### ---------------------------------------------------------------------------------------------------
#   FigS4 - plot temporal trend of CRT_VSL duration (=CRT_VSL)for 2015 & 2016 ############################## until line 172

source('funct/date_functions.r')
source('funct/plot.errorbars.r')
source('funct/yday2month.axis.r')
source('funct/textp.r')



## start plotting Figure S4 ## produces also CRT_VSLYYYY_list
library(oceanmap)
CRT_VSLYYYY_list <- list()

do.save <- F
ftype <- "png"
if(!do.save) x11(width=10, height=7)
if(do.save) figure(paste0("FigS4_CRT_VSL_", surfacedepth, "m"), folder = plot_folder, do.save=do.save, width=10, height=7, type=ftype)

par(mfrow=c(2, 2), mar=c(5, 4, 1, 1))
for(year in 2015:2016){
  CRT_VSLYYYY <-  subset(CRT_VSL, year(CRT_VSL$Start)==year)
  CRT_VSLYYYY$yday <- lubridate::yday(CRT_VSLYYYY$Start)
  CRT_VSLYYYY_list[[year-2014]] <- CRT_VSLYYYY
  
  # boxplot(CRT_VSLYYYY$CRT_VSLduration*60~CRT_VSLYYYY$yday, outline=F, ylim=c(0, 10))
  mean_sdYYYY <- plyr::ddply(CRT_VSLYYYY, c("yday"), summarise, 
                             mean = mean(CRT_VSLduration)*60, sd = sd(CRT_VSLduration)*60)
  
  mean_sdYYYY$date <- yday2date(mean_sdYYYY$yday, year)
  
  xlim <- lubridate::yday(range(as.Date(paste0(year, c("-08-01", "-10-31")))))
  dat <- mean_sdYYYY
  y <- dat$mean
  ylim <- c(0, 12)
  empty.plot(xlim=xlim, ylim=ylim, xlab=year);
  plot.errorbars(x = dat$yday, up = y-dat$sd, low = y+dat$sd, epsilon = 1)
  # lines(dat$yday, y)
  points(dat$yday, y, pch=19, col="blue")
  axis(2, lwd = 0, lwd.ticks = 1)
  yday2month.axis(months = 8:10, xpd=F)
  box()
  mtext(side = 2, text = "CRT_VSL (min)", line= 3, cex=.9)
  textp(xp = 5, yp = 90, font=2, LETTERS[year-2014], cex=1.3)
}

##### same plot but for CRT_VSL_School (CRT_VSL with applied MBP):
CRT_VSL_schoolYYYY_list <- list()
CRT_VSL_school <- c()
MBP=60
year <- 2015
for(year in 2015:2016){
  CRT_VSLYYYY <- CRT_VSLYYYY_list[[year-2014]]
  CRT_VSLmbp <- arrange(CRT_VSLYYYY, TagID, Start) 
  
  CRT_VSL_tmp <- plyr::ddply(CRT_VSLmbp, c("TagID", "yday"), mutate, 
                          Difftime = as.numeric(difftime(Start, lag(End), units = "secs")))
  
  #crt, cat surf
  CRT_VSL_tmp$Difftime <- ifelse(is.na(CRT_VSL_tmp$Difftime), 1000000, CRT_VSL_tmp$Difftime)
  CRT_VSL_tmp <- plyr::ddply(CRT_VSL_tmp, c("TagID", "yday"), mutate, 
                          slice = cumsum(Difftime>MBP))
  CRT_VSL_schoolYYYY <- plyr::ddply(CRT_VSL_tmp, c("TagID", "yday", "slice"), summarise, 
                             Start = min(Start), End=max(End))
  CRT_VSL_schoolYYYY$CRT_VSLduration <- as.numeric(difftime(CRT_VSL_schoolYYYY$End, CRT_VSL_schoolYYYY$Start, units = "secs"))+15
  CRT_VSL_schoolYYYY_list[[year-2014]] <- CRT_VSL_schoolYYYY
  CRT_VSL_school <- rbind(CRT_VSL_school, CRT_VSL_schoolYYYY)
  
  # mean(CRT_VSL_schoolYYYY$CRT_VSLduration/60)
  # median(CRT_VSL_schoolYYYY$CRT_VSLduration/60)
  # sd(CRT_VSL_schoolYYYY$CRT_VSLduration/60)

  #daily mean duration (Fig.S3)
  mean_sd <- plyr::ddply(CRT_VSL_schoolYYYY, c("yday"), summarise, 
                         mean = mean(CRT_VSLduration)/60, sd = sd(CRT_VSLduration)/60)
  mean_sd$date <- yday2date(mean_sd$yday, year)
  dat <- mean_sdMBPYYYY <- mean_sd
  
  xlim <- lubridate::yday(range(as.Date(paste0(year, c("-08-01", "-10-31")))))
  y <- dat$mean
  ylim <- c(0, 20)
  empty.plot(xlim=xlim, ylim=ylim, xlab=year);
  plot.errorbars(x = dat$yday, up = y-dat$sd, low = y+dat$sd, epsilon = 1)
  # lines(dat$yday, y)
  points(dat$yday, y, pch=19, col="blue")
  axis(2, lwd = 0, lwd.ticks = 1)
  yday2month.axis(months = 8:10, xpd=F)
  box()
  mtext(side = 2, text = "CRT_VSL^school (min)", line= 3, cex=.9)
  textp(xp = 5, yp = 90, font=2, LETTERS[year-2014+2], cex=1.3)
}
close_fig(do.save) ## done plotting Figure S4


### ---------------------------------------------------------------------------------------------------
#   Figure 8 - boxplot CRT VSL and CRT VSL ############################## until line 215
graphics.off()

#### Monthly Tests, boxplots (Fig5_CRT_VSL1m) and start Table 3
table3 <- list()

do.save <- F
ftype <- "png"
if(!do.save) x11(width=10, height=7)
if(do.save) figure(paste0("Fig8_CRT_VSL_", surfacedepth, "m"), folder = plot_folder, do.save=do.save, width=10, height=7, type=ftype)
test_out <- c()
par(mfrow=c(2, 2), mar=c(5, 4, 1, 1))

for(i in 1:4){
  if(i < 3) {dat <- CRT_VSLYYYY_list[[i]]; dat$CRT_VSLduration <- dat$CRT_VSLduration*60; ylim=c(0, 6); COL <- "grey"; type <- "CRT_VSL"}
  if(i >= 3) {dat <- CRT_VSL_schoolYYYY_list[[i-2]]; dat$CRT_VSLduration <- dat$CRT_VSLduration/60; ylim=c(0, 15); COL <- "white"; type <- "CRT_VSL_school"}
  year <- date2year(dat$Start[1])
  dat$Month <- date2month(dat$Start)
  sumstatCRT_VSL <- plyr::ddply(dat, c("Month"), summarise, 
                                    mean = mean(CRT_VSLduration), sd = sd(CRT_VSLduration), 
                                    sem = sd(CRT_VSLduration)/sqrt(length(CRT_VSLduration)))
  sumstatCRT_VSL$year <- year
  table3[[type]] <- rbind(table3[[type]], sumstatCRT_VSL)
  
  print(sumstatCRT_VSL, row.names = FALSE, sep='\t')
  
  subdat <- dat
  add1 <- data.frame(type=type, year = year, comp="all_months",different=kruskal.test(CRT_VSLduration ~ Month, data = subdat)$p.value <= 0.05)
  add2 <- data.frame(type=type, year = year, comp="8 vs 9",different=kruskal.test(CRT_VSLduration ~ Month, data = subdat[which(subdat$Month %in% c(8,9)),])$p.value <= 0.05)
  add3 <- data.frame(type=type, year = year, comp="9 vs 10",different=kruskal.test(CRT_VSLduration ~ Month, data = subdat[which(subdat$Month %in% c(9,10)),])$p.value <= 0.05)
  add4 <- data.frame(type=type, year = year, comp="8 vs 10",different=kruskal.test(CRT_VSLduration ~ Month, data = subdat[which(subdat$Month %in% c(8,10)),])$p.value <= 0.05)
  
  test_out <- rbind(test_out,add1,add2,add3,add4)
  
  boxplot(dat$CRT_VSLduration ~dat$Month, ylim=ylim, ylab=paste(type, " (min)"), 
          main="", xlab=year, outline=F, col=COL, names=num2month(8:10, abbrev = T))
  textp(xp = 5, yp = 90, font=2, LETTERS[i], cex=1.3)
}
close_fig(do.save)


### ---------------------------------------------------------------------------------------------------

####### calculate CRT_NSL & CRT_DL:

#########CRTs at daytime in zone for recovered tags
detach("package:dplyr", unload=TRUE)
detach("package:plyr", unload=TRUE)
library(dplyr)

subsurfacedepth=20 ## NSL-depth limit in meters 

CRT_NSL <- data.frame("changelayer"=numeric(), "TagID"=character(), "Start"=as.POSIXct(character()), "End"=as.POSIXct(character()), "Month"=numeric(), "duration"=numeric())
CRT_DL <- data.frame("changelayer"=numeric(), "TagID"=character(), "Start"=as.POSIXct(character()), "End"=as.POSIXct(character()), "Month"=numeric(), "duration"=numeric())


for (itag in tagrec) {
  cat("Running tag", itag, '\n')
  tagdata <- tsets[[itag]]
  # subsample tag data each 10 minutes
  resol=subset(resolution, tagname==itag)$resol #resolution
  npoints10 <- 600/resol #number of points corresponding to 10 minutes (600 seconds)
  tagdata <- tagdata[seq(1, nrow(tagdata), npoints10), ]
  tagdata <- subset(tagdata, daytime=="Day")
  tagdata <- in.zone(tagdata)
  tagdata <- subset(tagdata, in.zone==T)
  tagdata$month <- tagdata$date.long$mon+1
  tagdata$day <- tagdata$date.long$mday
  tagdata$inlayer  <- tagdata$Depth <= subsurfacedepth
  tagdata$date.long <- as.POSIXct(tagdata$date.long)
  #crt, cat 10m
  tagdata$changelayer <- cumsum(c(0, (diff(tagdata$inlayer))!=0 | (diff(tagdata$day))!=0))
  tagdatacrt <- subset(tagdata, tagdata$inlayer==T)
  tagdatacat <- subset(tagdata, tagdata$inlayer==F)

  # estimate crt duration
  CRT_NSL <- rbind(CRT_NSL, as.data.frame(tagdatacrt %>% group_by(changelayer) %>% 
                                 summarise(TagID=itag, Start = min(date.long), End=max(date.long), Month=min(month), duration=sum(inlayer)*600/3600))) # duration in hours
  CRT_DL <- rbind(CRT_DL, as.data.frame(tagdatacat %>% group_by(changelayer) %>% 
                                 summarise(TagID=itag, Start = min(date.long), End=max(date.long), Month=min(month), duration=sum(!inlayer)*600/3600))) # duration in hours
 
}  
#consider only August-October
CRT_NSL <- subset(CRT_NSL, CRT_NSL$Month %in% 8:10)
CRT_DL <- subset(CRT_DL, CRT_DL$Month %in% 8:10)

### ---------------------------------------------------------------------------------------------------

#### check correlation between subsequent crts:
out <- sm_out <- list()
for(i in 1:5){
  type <- c("CRT_VSL", "CRT_VSL_school", "CRT_NSL", "CRT_NSL", 'CRT_DL')[i]
  df <- get(type)
  df$duration <- df[[grep("duration",names(df))[1]]]
  head(df)
  for(tag in tagrec){
    df_tag <- df[which(df$TagID == tag),]
    df_tag$yday <- lubridate::yday(as.Date(df_tag$Start))
    head(df_tag)
    for(dd in unique(df_tag$yday)){
      input <- df_tag[which(df_tag$yday == dd),]
      n <- nrow(input)
      if(n > 1){
        add <- data.frame(d1=input$duration[1:(n-1)],d2=input$duration[2:n],yday=dd)
        out[[type]] <- rbind(out[[type]],add)
      }
    }
  }
  sm_out[[type]] <- round(cor(out[[type]]$d1,out[[type]]$d2),2)
  # plot(out[[type]]$d1,out[[type]]$d2)
}
sm_out


### ---------------------------------------------------------------------------------------------------


# Table 2 - Montly average CRT_VSL, CRT_VSL^school, CRT_NSL and CRT_DL recorded for the recovered tags ############################## until line 324

sumstat_all <- out_sm <- list()
CRT_VSL$duration <- CRT_VSL$CRT_VSLduration*60
CRT_VSL_school$duration <- CRT_VSL_school$CRT_VSLduration/60

for(i in 1:4){
  type <- c("CRT_VSL", "CRT_VSL_school", "CRT_NSL", 'CRT_DL')[i]
  type2 <- c("CRT_VSL", "CRT_VSL_school", "CRT_NSL", "CRT_DL")[i]
  dat <- get(type)  
  dat$Year <- date.long2year(dat$Start)
  dat$Month <- date.long2month(dat$Start)
  head(dat)
  
  # Summary statistics
  library(plyr)
  sumstat <- ddply(dat, c("Year", "Month"), summarise, 
                   mean = mean(duration), sd = sd(duration), 
                   sem = sd(duration)/sqrt(length(duration)))
  print(sumstat, row.names = FALSE, sep='\t') ### summary
  # sumstat$Month <- num2month(sumstat$Month)
  if(i == 1) out_sm[[1]] <- sumstat[, 1:2]
  out_sm[[type2]] <- sumstat_all[[type2]] <- round(sumstat, 1)
  out_sm[[type2]][[paste0(type2, "_mean_sd")]] <- paste0(out_sm[[type2]]$mean, " (", out_sm[[type2]]$sd, ")")
  out_sm[[type2]]$mean <- out_sm[[type2]]$sd <- out_sm[[type2]]$sem <- out_sm[[type2]]$Month <- out_sm[[type2]]$Year <- c()
  
}
# sumstat_all
out_df <- data.frame(out_sm, stringsAsFactors = F)
out_df$Month <- num2month(out_df$Month)
head(out_df)
write.csv(out_df, file = 'Tab2_mean_monthly_VSL_NSL_DL.csv')

### ---------------------------------------------------------------------------------------------------
#   Fig.S5 - plot temporal trend of CRT_NSL & CRT_DL duration for 2015 & 2016 ##############################  until line 374

do.save <- F
ftype <- "png"
if(!do.save) x11(width=10, height=7)
if(do.save) figure(paste0("FigS5_CRT_NSL_DL_", subsurfacedepth, "m"), folder = plot_folder, do.save=do.save, width=10, height=7, type=ftype)
k <- 1
par(mfrow=c(2, 2))
for(i in 1:2){
  type <- c("CRT_NSL", 'CRT_DL')[i]
  type2 <- c("CRT_NSL", "CRT_DL")[i]
  dat <- get(type)  
  
  
  # Summary statistics
  library(plyr)
  print(subsurfacedepth)
  summary(dat)
  sumstat <- ddply(dat, c("Month"), summarise, 
                   mean = mean(duration), sd = sd(duration), 
                   sem = sd(duration)/sqrt(length(duration)))
  print(sumstat, row.names = FALSE, sep='\t') ### summary
  
  for(year in 2015:2016){
    
    subdat <- subset(dat, year(dat$Start)==year)
    subdat$yday <- lubridate::yday(subdat$Start)
    
    mean_sdYYYY <- plyr::ddply(subdat, c("yday"), summarise, 
                               mean = mean(duration)*60, sd = sd(duration)*60)
    mean_sdYYYY$date <- yday2date(mean_sdYYYY$yday, year)
    
    plotdat <- mean_sdYYYY
    y <- plotdat$mean/60
    ylim <- c(0, 12)
    empty.plot(xlim=xlim, ylim=ylim, xlab=year);
    plot.errorbars(x = plotdat$yday, up = y-plotdat$sd/60, low = y+plotdat$sd/60, epsilon = 1)
    # lines(plotdat$yday, y)
    points(plotdat$yday, y, pch=19, col="blue")
    axis(2, lwd = 0, lwd.ticks = 1)
    yday2month.axis(months = 8:10, xpd=F)
    box()
    mtext(side = 2, text = paste(type2, "(h)"), line= 3, cex=.9)
    textp(xp = 5, yp = 90, font=2, LETTERS[k], cex=1.3)
    k <- k + 1
  }
}
close_fig(do.save)

 
### ---------------------------------------------------------------------------------------------------
#### Figure 10 Monthly Tests, boxplots (Figs 10) and complete Table 3 (test results table, not given in paper) ##### until line 432

graphics.off()

do.save <- F
ftype <- "png"
if(!do.save) x11(width=10, height=7)
if(do.save) figure(paste0("Fig10_CRT_NSL_DL_", subsurfacedepth, "m"), folder = plot_folder, do.save=do.save, width=10, height=7, type=ftype)

par(mfrow=c(2, 2), mar=c(5, 4, 1, 1))
k <- 1
# test_out <- c()
for(i in 1:2){
  type <- c("CRT_NSL", 'CRT_DL')[i]
  type2 <- c("CRT_NSL", "CRT_DL")[i]
  dat <- get(type); dat$year <- date2year(dat$Start)
  ylim=c(0, c(7, 4)[i]) 
  COL <- c("grey", "white")[i]
  
  for(year in 2015:2016){
    subdat <- dat[which(dat$year == year), ]
    sumstat <- plyr::ddply(subdat, c("Month"), summarise, 
                           mean = mean(duration), sd = sd(duration), 
                           sem = sd(duration)/sqrt(length(duration)))
    sumstat$year <- year
    table3[[type2]] <- rbind(table3[[type2]], sumstat)
    
    print(sumstat, row.names = FALSE, sep='\t')
    add1 <- data.frame(type=type, year = year, comp="all_months",different=kruskal.test(duration/60 ~ Month, data = subdat)$p.value <= 0.05)
    add2 <- data.frame(type=type, year = year, comp="8 vs 9",different=kruskal.test(duration/60 ~ Month, data = subdat[which(subdat$Month %in% c(8,9)),])$p.value <= 0.05)
    add3 <- data.frame(type=type, year = year, comp="9 vs 10",different=kruskal.test(duration/60 ~ Month, data = subdat[which(subdat$Month %in% c(9,10)),])$p.value <= 0.05)
    add4 <- data.frame(type=type, year = year, comp="8 vs 10",different=kruskal.test(duration/60 ~ Month, data = subdat[which(subdat$Month %in% c(8,10)),])$p.value <= 0.05)
    
    test_out <- rbind(test_out,add1,add2,add3,add4)
 
    boxplot(subdat$duration ~ subdat$Month, ylim=ylim, ylab=paste(type2, " (h)"), 
            main="", xlab=year, outline=F, col=COL, names=num2month(8:10, abbrev = T))
    textp(xp = 5, yp = 90, font=2, LETTERS[k], cex=1.3)
    k <- k + 1
  }
}
close_fig(do.save)
test_out


lapply(table3, function(y) apply(y, 2, function(x)round(x, 1))) ### check finished table3

test_out[which(test_out$type == "CRT_VSL"),]
test_out[which(test_out$type == "CRT_VSL_school"),]
test_out[which(test_out$type == "CRT_NSL"),]
test_out[which(test_out$type == "CRT_DL"),]

write.csv(test_out, file = './results/Kruskal_Wallis_test_results_0_20m.csv')



### ---------------------------------------------------------------------------------------------------

crtcatjoin_list <- list()
for(i in 1:2){
  crt_vsl <- get(paste0("CRT_VSL",c("","_school")[i]))
  crt_nsl <- get(paste0("CRT_NSL",c("","")[i]))
  
  ## Join CRT at resolution 10 minutes with instantaneous surface events to find CAT_VSL
  add <- data.frame("changelayer"=numeric(), "TagID"=character(), "Start"=as.POSIXct(character()), "End"=as.POSIXct(character()), "Month"=numeric(), "CRT_VSLduration"=numeric(), 
                           "StartCRT_NSL"=as.POSIXct(character()), "EndCRT_NSL"=as.POSIXct(character()), "CRTduration_NSL"=numeric(), "vecindex"=integer(), "CAT_VSL"=numeric())
  for (itag in tagrec) {
    CRT_NSLtag <- subset(crt_nsl, TagID==itag)
    CRT_VSLtag <- subset(crt_vsl, TagID==itag)
    if(nrow(CRT_VSLtag)>0){
      index <- findInterval(CRT_VSLtag$Start, CRT_NSLtag$Start, all.inside = F) # find CRT_NSL for each CRT_VSL (several CRT_VSL can have same CRT_NSL) 
      index <- ifelse(index==0, NA, index)
      
            ## rename columns:
      vecstart <- CRT_NSLtag[index, c('Start', 'End', 'duration')]  # duration in hours
      names(vecstart)=c('StartCRT_NSL', 'EndCRT_NSL', 'CRTduration_NSL')
      CRT_VSLtag <- cbind(CRT_VSLtag, vecstart)
      CRT_VSLtag <- na.omit(CRT_VSLtag)
      CRT_VSLtag <- subset(CRT_VSLtag, CRT_VSLtag$End<=CRT_VSLtag$EndCRT_NSL)
      vecindex <- cumsum(c(1, (diff(CRT_VSLtag$StartCRT_NSL)!=0)))
      
      CRT_VSLtag <- cbind(CRT_VSLtag, vecindex)       
      CRT_VSLtag$CAT_VSL <- ifelse(c(diff(CRT_VSLtag$vecindex), NA)==0, difftime(lead(CRT_VSLtag$Start), CRT_VSLtag$End, unit="hour"), NA) #time between surface presence
      add <- rbind(add, CRT_VSLtag)
    }
  }
  add$CAT_VSLmin <- add$CAT_VSL*60
  add$CRT_VSLmin <- add$CRT_VSLduration/60
  
  # add different index for each CRT_NSL
  vecindex <- cumsum(c(1, (diff(add$StartCRT_NSL)!=0))) 
  add$vecindex <- vecindex  
  crtcatjoin_list[[i]] <- add
}

crtcatjoin_list

fname <- "./results/bluemed_corr_test.rd"
save(crtcatjoin_list, file=fname)
load(fname, verbose = T)


####### Fig11 Count how many surfacing events occur for each CRT_NSL: mean occurrence per time provides probability of being at surface ################ done at line 559
library(minpack.lm)
library(plyr); library(dplyr)
source("./funct/add.legend.r")


do.save <- F
ftype <- "png"
if(!do.save) x11(width=12.5, height=4.9)
if(do.save) figure(paste0("Fig11_corr_nsurf_CRT_NSL_", subsurfacedepth, "m"), folder = plot_folder, 
                   do.save=do.save, width=12.5, height=4.9, type=ftype)

par(mfrow=c(1,2),las=1)
out <- c()
for(i in 1:2){
  crtcatjoin <- crtcatjoin_list[[i]]
  crtcatjoin <- ddply(crtcatjoin, .(vecindex), transform, count=length(vecindex)) # sum up index from different NSL events
  crtcatjoin$Month <- date.long2month(crtcatjoin$Start)
  head(crtcatjoin)
  ### get unique surface events:
  # crtcatjoincount <- unique(crtcatjoin[c("TagID", "Month", "StartCRT_NSL", "EndCRT_NSL", "CRTduration_NSL", "vecindex", "count")])
  # crtcatjoincount$month <- as.factor(crtcatjoincount$Month)
  
  ### calc correlations per month
  crtcatjoincormonth <- ddply(crtcatjoin, .(Month), transform, cor=cor(CRTduration_NSL, count), countmonth=length(Month)) 
  crtcatjoincormonth <- unique(crtcatjoincormonth[c("Month", "cor", "countmonth")])
  print(crtcatjoincormonth, row.names=F)
  
  ### calculate slope of regression line:
  add <- c()
  for(m in 8:10){
    dat <- crtcatjoin[which(crtcatjoin$Month == m),]

    y <- dat$count
    x <- dat$CRTduration_NSL
    mod <- nlsLM(y ~ a*x, start=list(a=10),
                 control=nls.lm.control(maxiter=200))
    # lines(x, fitted(mod), col = m-6, lwd = 2)
    add <- rbind(add,data.frame(month=m,a=coef(mod))) # number of surface events by hour
  }
  crtcatjoincormonth$a <- round(add$a,1)
  crtcatjoincormonth$SET <- c("IND","SCHOOL")[1]
  out <- rbind(out,crtcatjoincormonth)
  
  pdat <- crtcatjoin
  pdat$CRTduration_NSL_rounded <- round(pdat$CRTduration_NSL*2)/2
  
  pdat <- pdat[which(pdat$CRTduration_NSL_rounded <= 13),]
  head(pdat)
  x2 <- factor(pdat$CRTduration_NSL_rounded,levels=seq(0,13,by=.5))
  y2 <- pdat$count
  boxplot(y2~x2,axes=F,xlab="",ylab="")
  n <- length(levels(x2))
  AT <- seq(1,n,by=2)
  axis(1,at=AT,labels = levels(x2)[AT],lwd.ticks = 1,lwd=0)
  axis(2,lwd.ticks = 1,lwd=0)
  box()
  title(xlab=c("CRT_NSL (h)","CRT_NSL of tuna schools (h)")[1])
  title(ylab=c("Surface events (n)","Surface events of tuna schools (n)")[i])
  

  x2new <- seq(0,14,by=.5)
  x3new <- 1:length(x2new)
  
  y <- y2
  x <- as.numeric(as.character(x2))
  mod <- nlsLM(y ~ a*x, start=list(a=10),
               control=nls.lm.control(maxiter=200))
  y2new <- predict(mod,data.frame(x=x2new))
  lines(x3new,y2new,col="red")
  print(coefficients(mod))
  coef <- round(coefficients(mod),2)
  add.legendp(xp = 17,yp = 90, col = "red", vals = paste0("f(x) = ",coef,"x"),lwd=1,box.lwd=0)
}
close_fig(do.save)

out
tab_name <- "results/Corr_nsurf_CRT_NSL.csv"
write.csv(out,file=tab_name)



### P-value ≤ α: The differences between some of the medians are statistically significant 
head(crtcatjoin)
crtcatjoin$year <- date.long2year(crtcatjoin$StartCRT_NSL)
kruskal.test(count ~ year, data = crtcatjoin)
kruskal.test(count ~ Month, data = crtcatjoin)

# kruskal.test(count ~ Month, data = subset(crtcatjoin, Month==8 | Month ==10)) #Sept and Oct are the same
kruskal.test(count ~ Month, data = crtcatjoin[which(crtcatjoin$Month %in% c(8,9) & crtcatjoin$year == 2015),]) #Aug and Sept are the same
kruskal.test(count ~ Month, data = crtcatjoin[which(crtcatjoin$Month %in% c(9,10) & crtcatjoin$year == 2015),]) #Sept and Oct are the same
kruskal.test(count ~ Month, data = crtcatjoin[which(crtcatjoin$Month %in% c(8,10) & crtcatjoin$year == 2015),]) #Aug and Oct are the same

kruskal.test(count ~ Month, data = crtcatjoin[which(crtcatjoin$Month %in% c(8,9) & crtcatjoin$year == 2016),]) #Sept and Oct are the same
kruskal.test(count ~ Month, data = crtcatjoin[which(crtcatjoin$Month %in% c(9,10) & crtcatjoin$year == 2016),]) #Sept and Oct are the same
kruskal.test(count ~ Month, data = crtcatjoin[which(crtcatjoin$Month %in% c(8,10) & crtcatjoin$year == 2016),]) #Sept and Oct are the same

