date2year <- function(x){
  as.numeric(format(as.Date(x),"%Y"))
}

month2date <- function(month,year=0,day=1){
  as.Date(paste0(year,"-",month,"-",day))
}

mid.month2date <- function(month,year=0,day=15){
  as.Date(paste0(year,"-",month,"-",day))
}

date2month <- function(x,numeric=T,abbreviate=T){
  x <- fact2Date(x)
  
  if(numeric){
    output <- as.numeric(format(as.Date(x),"%m"))
  }else{
    lct <- Sys.getlocale("LC_TIME"); Sys.setlocale("LC_TIME", "C")
    output <- format(as.Date(x),"%B")
    if(abbreviate) output <- format(as.Date(x),"%b")
  }
  return(output)
}

date2day <- function(x){
  as.numeric(format(as.Date(x),"%d"))
}

date.long2hour <- function(x){
  as.numeric(format(x,"%H"))
}

date.long2year <- function(x){
  as.numeric(format(x,"%Y"))
}

date.long2day <- function(x){
  as.numeric(format(x,'%d'))
}


date.long2zero.date.long <- function(date.long){
  inst.pkg(lubridate)
  out <- fact2Date.long("0000-01-01")+yday(date.long)*24*60*60+date.long2hour.dc(date.long)*60*60
  return(out)
}

date.long2hour.dc <- function(x){
  as.numeric(format(x,"%H"))+as.numeric(format(x,"%M"))/60+as.numeric(format(x,"%S"))/(60*60)
}

date.long2min.dc <- function(x){
  as.numeric(format(x,"%M"))+as.numeric(format(x,"%S"))/60
}

date.long2min <- function(x){
  as.numeric(format(x,"%M"))
}

date_hour.dc2date.long <- function(Date,hour.dc,tz="UTC"){
  d0 <- as.numeric(date2date.long(Date,tz = tz,midday = F))
  out <- num2date.long(d0,tz = tz,hours.offset = hour.dc)
  return(out)
}

date2date.long <- function(x,tz="",midday=T){
  sstart <- 12
  if(!midday) sstart <- 0
  strptime(paste(fact2Date(x),paste0(sstart,":00:00")),"%Y-%m-%d %H:%M:%S",tz = tz)
}

num2date <- function(x){
  if(class(x) != "Date"){
    out <- as.Date(x,origin="1970-01-01")
  }else{
    out <- x
  }
  return(out)
}

num2date.long <- function(x,tz,hours.offset=1){
  if(any(hours.offset==1)) warning("ATTENTION! hours.offset not set to 0!")
  out <- fact2Date.long("1970-01-01 00:00:00",tz=tz)+x+hours.offset*(60*60)
  return(out)
}

fact2Date <- function(x) as.Date(as.character(x))

fact2Date.long <- function(x,tz="UTC") {
  out <- as.POSIXct(strptime(as.character(x),"%Y-%m-%d %H:%M:%S",tz=tz))
  i <- which(is.na(out))
  out[i] <- as.POSIXct(strptime(paste(x[i],"00:00:00"),"%Y-%m-%d %H:%M:%S",tz=tz))
  return(out)
}

date.long2time <- function(x,do.secs=T) {
  out <- format(x,"%H:%M:%S")
  if(!do.secs) out <- format(x,"%H:%M")
  return(out)
}
fact2num <- function(x){
  as.numeric(as.character(x))
} 

num2month <- function(m,english=T,abbrev=F){
  if(english) lct <- Sys.getlocale("LC_TIME"); Sys.setlocale("LC_TIME", "C")
  dat <- m
  if(class(m) != "Date") dat <- as.Date(paste0("2012-",m,"-1"))
  Dat <- format(as.Date(dat),"%B")
  if(abbrev) Dat <- format(as.Date(dat),"%b")
  return(Dat)
}

date2season <- function(x){
  if(!is.numeric(x)) x <- date2month(x)
  month <- data.frame(month=x,id=1:length(x))
  
  add <- as.data.frame(rbind(
    cbind("winter",c(1:2,12)),
    cbind("spring",3:5),
    cbind("summer",6:8),
    cbind("autumn",9:11)))
  names(add) <- c('season','month')
  
  seasons <- merge(month,add,by='month',all.x=T)
  seasons <- seasons[order(seasons$id),]
  return(as.character(seasons$season))
}



date2tuna.season <- function(x){
  if(!is.numeric(x)) x <- date2month(x)
  month <- data.frame(month=x,id=1:length(x))
  
  add <- as.data.frame(rbind(
    cbind("winter",c(1:2,12)),
    cbind("spring",3:5),
    cbind("summer",6:8),
    cbind("autumn",9:11)))
  names(add) <- c('season','month')
  add$month <- fact2num(add$month)
  
  inst.pkg(plyr)
  resume <- ddply(add,.(season),function(x){
    if(max(x$month) != 12){
      out <- paste(min(x$month),max(x$month),sep="-")
    }else{
      out <- paste(max(x$month),max(x$month[x$month < 6]),sep="-")
    }
    c(range=out)
  })
  df.order <- data.frame(season=c('winter','spring','summer','autumn'),order=1:4)
  resume <- merge(resume,df.order,by='season')
  resume <- resume[order(resume$order),]
  
  cat('applying season definition:\n')
  cat.table(resume[,1:2])
  
  seasons <- merge(month,add,by='month',all.x=T)
  seasons <- seasons[order(seasons$id),]
  return(as.character(seasons$season))
}

date.long2sec <- function(x) as.numeric(format(x,'%S'))
date.long2min <- function(x) as.numeric(format(x,'%M'))
date.long2month <- function(x) as.numeric(format(x,'%m'))


date2interval <- function(x,ndays,all=F){
  library("lubridate")
  library(plyr)
  add0 <- data.frame(yday=1:365)
  add0$date <- as.Date('0-1-1')+add0$yday-1
  add0$interval <- 1+trunc(add0$yday/ndays)
  add1 <- ddply(add0,.(interval),function(x)c(interval_long=paste(format(range(x$date),"%d.%b"),collapse="_")))
  add <- merge(add1,add0,by="interval")
  add$date <- c()
  if(class(x) == "Date"){
    xdf <- data.frame(date=x,yday=yday(x))
  }else if(class(x) == "data.frame"){
    xdf <- x; xdf$yday <- yday(xdf$date)
  }
  out <- merge(xdf,add,by="yday",all=all)
  return(out)
}

yday2date <- function(ydays,year){
  dates <- (as.Date(paste0(year,'-01-01'))-1)+ydays
  return(dates)
}

